@@ -70,12 +70,12 @@ class Entry(Gtk.EventBox):
 	bind "<Control>K" { "delete-from-cursor" (display-line-ends, 1) };
 	bind "<Control>E" { "move-cursor" (buffer-ends, 1, 0) };
 	bind "Escape" { "delete-from-cursor" (display-lines, 1) };
-};
+}
 
 GtkEntry#gedit-commander-entry {
-	gtk-key-bindings: terminal-like-bindings
+	gtk-key-bindings: terminal-like-bindings;
 }
-""", -1)
+""")
 
 		# FIXME: remove hardcopy of 600 (GTK_STYLE_PROVIDER_PRIORITY_APPLICATION)
 		# https://bugzilla.gnome.org/show_bug.cgi?id=646860
