@@ -806,11 +806,7 @@ class DocumentHelper(Signals):
             self.remove_edit_points()
 
         iterwas = buf.get_iter_at_mark(wasat)
-
-        if hasattr(where, 'assign'):
-            where.assign(iterwas)
-        elif hasattr(Gedit, 'utils_text_iter_assign'):
-            Gedit.utils_text_iter_assign(where, iterwas)
+        where.assign(iterwas)
 
         if atinsert:
             buf.move_mark(buf.get_insert(), iterwas)
@@ -901,13 +897,8 @@ class DocumentHelper(Signals):
                 piter = buf.get_iter_at_mark(orig)
                 buf.delete_mark(orig)
 
-                # To be able to have it not crash with old pygtk
-                if hasattr(start, 'assign'):
-                    start.assign(piter)
-                    end.assign(piter)
-                elif hasattr(Gedit, 'utils_text_iter_assign'):
-                    Gedit.utils_text_iter_assign(start, piter)
-                    Gedit.utils_text_iter_assign(end, piter)
+                start.assign(piter)
+                end.assign(piter)
             else:
                 self.remove_edit_points()
 
@@ -1037,7 +1028,7 @@ class DocumentHelper(Signals):
         if not self._edit_points:
             return
 
-        clipboard = Gtk.Clipboard.get_for_display(self._view.get_display())
+        clipboard = Gtk.Clipboard.get_for_display(self._view.get_display(), Gdk.SELECTION_CLIPBOARD)
         self._paste_mark = self._buffer.create_mark(None, self._buffer.get_iter_at_mark(self._buffer.get_insert()), True)
 
         clipboard.request_text(self.on_clipboard_text)
